@@ -11,7 +11,7 @@
 # IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 # WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
-# rcsid: "@(#) $Id: Server.dat,v 1.14 2000/01/19 07:49:40 spider Exp $"
+# rcsid: "@(#) $Id: Server.dat,v 1.15 2000/08/05 20:33:14 spider Exp $"
 
 package Net::UNIX::Server;
 use 5.004_04;
@@ -23,7 +23,7 @@ sub croak { require Carp; goto &Carp::croak; }
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
 BEGIN {
-    $VERSION = '0.93';
+    $VERSION = '0.933';
     eval "sub Version { __PACKAGE__ . ' v$VERSION' }";
 }
 
@@ -125,13 +125,20 @@ Net::UNIX::Server - UNIX-domain sockets interface module for listeners
 
 The C<Net::UNIX::Server> module provides additional
 services for UNIX-domain socket
-communication.  It is layered atop the C<Net::UNIX> and C<Net::Gen> modules,
+communication.  It is layered atop the
+L<C<Net::UNIX>|Net::UNIX>
+and
+L<C<Net::Gen>|Net::Gen>
+modules,
 which are part of the same distribution.
 
 =head2 Public Methods
 
 The following methods are provided by the C<Net::UNIX::Server> module
-itself, rather than just being inherited from C<Net::UNIX> or C<Net::Gen>.
+itself, rather than just being inherited from
+L<C<Net::UNIX>|Net::UNIX>
+or
+L<C<Net::Gen>|Net::Gen>.
 
 =over 4
 
@@ -157,7 +164,7 @@ The examples above show the indirect object syntax which many prefer,
 as well as the guaranteed-to-be-safe static method call.  There
 are occasional problems with the indirect object syntax, which
 tend to be rather obscure when encountered.  See
-E<lt>URL:http://www.rosat.mpe-garching.mpg.de/mailing-lists/perl-porters/1998-01/msg01674.htmlE<gt>
+http://www.rosat.mpe-garching.mpg.de/mailing-lists/perl-porters/1998-01/msg01674.html
 for details.
 
 See L<Net::TCP::Server> for an example of running a server.  The
@@ -237,7 +244,8 @@ just yet.)
 
 =head1 SEE ALSO
 
-Net::UNIX(3), Net::Gen(3)
+L<Net::UNIX(3)|Net::UNIX>,
+L<Net::Gen(3)|Net::Gen>
 
 =head1 AUTHOR
 
